---
name: Feature Request
about: Suggest an idea for this project
title: 'Feature:'
labels: enhancement
assignees: ''
---

To suggest an idea or ask about a feature, a new Message Broker supporting or something else, please follow this template:

**Is your feature request related to a problem? Please describe.**
A clear and concise description of what the problem is. Ex. I'm always frustrated when [...]

**Describe the solution you'd like**
A clear and concise description of what you want to happen.

**Feature code example**
Please, to show others how you image the feature syntax, illustrate it by the **Propan** code example

```python
from propan import PropanApp
...
```

**Describe alternatives you've considered**
A clear and concise description of any alternative solutions or features you've considered.

**Additional context**
Add any other context or screenshots about the feature request here.
